#!/usr/bin/env python
import sys
import unittest
try:
    from StringIO import StringIO
except ImportError:
    from io import StringIO  # NOQA
from update_checker import UpdateChecker, update_check


class UpdateCheckerTest(unittest.TestCase):
    TRACKED_PACKAGE = 'praw'
    UNTRACKED_PACKAGE = 'requests'

    def test_checker_check__bad_url(self):
        checker = UpdateChecker('http://sdlkjsldfkjsdlkfj.com')
        checker.bypass_cache = True
        self.assertFalse(checker.check(self.TRACKED_PACKAGE, '0.0.1'))

    def test_checker_check__no_update_to_beta_version(self):
        checker = UpdateChecker()
        checker.bypass_cache = True
        self.assertFalse(checker.check(self.TRACKED_PACKAGE, '3.6'))

    def test_check_check__untracked_package(self):
        checker = UpdateChecker()
        checker.bypass_cache = True
        self.assertEqual("update_checker does not support 'requests'",
                         checker.check(self.UNTRACKED_PACKAGE, '0.0.1'))

    def test_checker_check__update_to_beta_version_from_beta_version(self):
        checker = UpdateChecker()
        checker.bypass_cache = True
        self.assertTrue(checker.check(self.TRACKED_PACKAGE, '4.0.0b4'))

    def test_checker_check__update_to_rc_version_from_beta_version(self):
        checker = UpdateChecker()
        checker.bypass_cache = True
        self.assertTrue(checker.check(self.TRACKED_PACKAGE, '4.0.0b4'))

    def test_checker_check__successful(self):
        checker = UpdateChecker()
        checker.bypass_cache = True
        result = checker.check(self.TRACKED_PACKAGE, '1.0.0')
        self.assertTrue(result is not None)

    def test_update_check__successful(self):
        prev_stdout = sys.stdout
        sys.stdout = StringIO()
        try:
            update_check(self.TRACKED_PACKAGE, '0.0.1', bypass_cache=True)
        finally:
            result = sys.stdout
            sys.stdout = prev_stdout
        self.assertTrue(len(result.getvalue()) > 0)

    def test_update_check__unsuccessful(self):
        prev_stdout = sys.stdout
        sys.stdout = StringIO()
        try:
            update_check(self.TRACKED_PACKAGE, '0.0.1', bypass_cache=True,
                         url='http://sdlkjsldfkjsdlkfj.com')
        finally:
            result = sys.stdout
            sys.stdout = prev_stdout
        self.assertTrue(len(result.getvalue()) == 0)

    def test_update_check__untracked_package(self):
        prev_stdout = sys.stdout
        sys.stdout = StringIO()
        try:
            update_check(self.UNTRACKED_PACKAGE, '0.0.1', bypass_cache=True)
        finally:
            result = sys.stdout
            sys.stdout = prev_stdout
        self.assertEqual("update_checker does not support 'requests'\n",
                         result.getvalue())


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python
import os
import re
from setuptools import setup

MODULE_NAME = 'update_checker'

with open(os.path.join(os.path.dirname(__file__), 'README.md')) as fp:
    README = fp.read()
with open('{0}.py'.format(MODULE_NAME)) as fp:
    VERSION = re.search("__version__ = '([^']+)'", fp.read()).group(1)

setup(name=MODULE_NAME,
      author='Bryce Boe',
      author_email='bbzbryce@gmail.com',
      classifiers=['Intended Audience :: Developers',
                   'License :: OSI Approved :: BSD License',
                   'Operating System :: OS Independent',
                   'Programming Language :: Python',
                   'Programming Language :: Python :: 2.7',
                   'Programming Language :: Python :: 3',
                   'Programming Language :: Python :: 3.3',
                   'Programming Language :: Python :: 3.4',
                   'Programming Language :: Python :: 3.5'],
      description='A python module that will check for package updates.',
      install_requires=['requests>=2.3.0'],
      license='Simplified BSD License',
      long_description=README,
      py_modules=[MODULE_NAME, '{0}_test'.format(MODULE_NAME)],
      test_suite='update_checker_test',
      url='https://github.com/bboe/update_checker',
      version=VERSION)
